@@ -1,6 +1,6 @@
 #!/bin/sh
 # This file is part of Firejail project
-# Copyright (C) 2014-2022 Firejail Authors
+# Copyright (C) 2014-2025 Firejail Authors
 # License GPL v2
 
 # based on http://tldp.org/HOWTO/html_single/Debian-Binary-Package-Building-HOWTO/
@@ -10,10 +10,6 @@ set -e
 
 . "$(dirname "$0")/config.sh"
 
-EXTRA_VERSION=$1
-
-test "$#" -gt 0 && shift
-
 CODE_ARCHIVE="$TARNAME-$VERSION.tar.xz"
 CODE_DIR="$TARNAME-$VERSION"
 INSTALL_DIR="${INSTALL_DIR}${CODE_DIR}/debian"
@@ -29,8 +25,8 @@ echo "*****************************************"
 tar -xJvf "$CODE_ARCHIVE"
 #mkdir -p "$INSTALL_DIR"
 cd "$CODE_DIR"
-./configure --prefix=/usr "$@"
-make -j2
+./configure --prefix=/usr --enable-apparmor "$@"
+make -j "$(nproc)"
 mkdir debian
 DESTDIR=debian make install-strip
 
@@ -55,7 +51,7 @@ chmod 644 "$DEBIAN_CTRL_DIR/conffiles"
 find "$INSTALL_DIR" -type d -exec chmod 755 '{}' +
 cd "$CODE_DIR"
 fakeroot dpkg-deb --build debian
-lintian --no-tag-display-limit debian.deb
+# lintian --no-tag-display-limit debian.deb
 mv debian.deb "../firejail_${VERSION}${EXTRA_VERSION}_1_$(dpkg-architecture -qDEB_HOST_ARCH).deb"
 cd ..
 rm -fr "$CODE_DIR"
