@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -20,11 +20,14 @@
 
 #include "firecfg.h"
 #include "../include/firejail_user.h"
+#include <glob.h>
+
 int arg_debug = 0;
 char *arg_bindir = "/usr/local/bin";
 int arg_guide = 0;
+int done_config = 0;
 
-static char *usage_str =
+static const char *const usage_str =
 	"Firecfg is the desktop configuration utility for Firejail software. The utility\n"
 	"creates several symbolic links to firejail executable. This allows the user to\n"
 	"sandbox applications automatically, just by clicking on a regular desktop\n"
@@ -57,13 +60,16 @@ static char *usage_str =
 	"   [...]\n"
 	"\n"
 	"License GPL version 2 or later\n"
-	"Homepage: https://firejail.wordpress.com\n\n";
+	"Homepage: https://firejail.wordpress.com\n";
 
-static void usage(void) {
-	printf("firecfg - version %s\n\n", VERSION);
-	puts(usage_str);
+static void print_version(void) {
+	printf("firecfg version %s\n\n", VERSION);
 }
 
+static void usage(void) {
+	print_version();
+	puts(usage_str);
+}
 
 static void list(void) {
 	DIR *dir = opendir(arg_bindir);
@@ -73,10 +79,6 @@ static void list(void) {
 		exit(1);
 	}
 
-	char *firejail_exec;
-	if (asprintf(&firejail_exec, "%s/bin/firejail", PREFIX) == -1)
-		errExit("asprintf");
-
 	struct dirent *entry;
 	while ((entry = readdir(dir)) != NULL) {
 		if (strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0)
@@ -89,7 +91,7 @@ static void list(void) {
 		if (is_link(fullname)) {
 			char* fname = realpath(fullname, NULL);
 			if (fname) {
-				if (strcmp(fname, firejail_exec) == 0)
+				if (strcmp(fname, FIREJAIL_EXEC) == 0)
 					printf("%s\n", fullname);
 				free(fname);
 			}
@@ -98,7 +100,6 @@ static void list(void) {
 	}
 
 	closedir(dir);
-	free(firejail_exec);
 }
 
 static void clean(void) {
@@ -111,10 +112,6 @@ static void clean(void) {
 		exit(1);
 	}
 
-	char *firejail_exec;
-	if (asprintf(&firejail_exec, "%s/bin/firejail", PREFIX) == -1)
-		errExit("asprintf");
-
 	struct dirent *entry;
 	while ((entry = readdir(dir)) != NULL) {
 		if (strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0)
@@ -127,7 +124,7 @@ static void clean(void) {
 		if (is_link(fullname)) {
 			char* fname = realpath(fullname, NULL);
 			if (fname) {
-				if (strcmp(fname, firejail_exec) == 0) {
+				if (strcmp(fname, FIREJAIL_EXEC) == 0) {
 					char *ptr = strrchr(fullname, '/');
 					assert(ptr);
 					ptr++;
@@ -144,10 +141,43 @@ static void clean(void) {
 	}
 
 	closedir(dir);
-	free(firejail_exec);
 	printf("\n");
 }
 
+#define ignorelist_maxlen 2048
+static const char *ignorelist[ignorelist_maxlen];
+static int ignorelist_len = 0;
+
+static int append_ignorelist(const char *const str) {
+	assert(str);
+	if (ignorelist_len >= ignorelist_maxlen) {
+		fprintf(stderr, "Warning: Ignore list is full (%d/%d), skipping %s\n",
+			ignorelist_len, ignorelist_maxlen, str);
+		return 0;
+	}
+
+	printf("   ignoring '%s'\n", str);
+	const char *const dup = strdup(str);
+	if (!dup)
+		errExit("strdup");
+
+	ignorelist[ignorelist_len] = dup;
+	ignorelist_len++;
+
+	return 1;
+}
+
+int in_ignorelist(const char *const str) {
+	assert(str);
+	int i;
+	for (i = 0; i < ignorelist_len; i++) {
+		if (strcmp(str, ignorelist[i]) == 0)
+			return 1;
+	}
+
+	return 0;
+}
+
 static void set_file(const char *name, const char *firejail_exec) {
 	if (which(name) == 0)
 		return;
@@ -162,35 +192,29 @@ static void set_file(const char *name, const char *firejail_exec) {
 		if (rv) {
 			fprintf(stderr, "Error: cannot create %s symbolic link\n", fname);
 			perror("symlink");
-		}
-		else
+		} else {
 			printf("   %s created\n", name);
-	}
-	else {
-	  fprintf(stderr, "Warning: cannot create %s - already exists! Skipping...\n", fname);
+		}
+	} else {
+		fprintf(stderr, "Warning: cannot create %s - already exists! Skipping...\n", fname);
 	}
 
 	free(fname);
 }
 
-// parse /etc/firejail/firecfg.config file
-static void set_links_firecfg(void) {
-	char *cfgfile;
-	if (asprintf(&cfgfile, "%s/firecfg.config", SYSCONFDIR) == -1)
-		errExit("asprintf");
+// parse a single config file
+static void parse_config_file(const char *cfgfile, int do_symlink) {
+	if (do_symlink)
+		printf("Configuring symlinks in %s\n", arg_bindir);
 
-	char *firejail_exec;
-	if (asprintf(&firejail_exec, "%s/bin/firejail", PREFIX) == -1)
-		errExit("asprintf");
+	printf("Parsing %s\n", cfgfile);
 
-	// parse /etc/firejail/firecfg.config file
 	FILE *fp = fopen(cfgfile, "r");
 	if (!fp) {
 		perror("fopen");
 		fprintf(stderr, "Error: cannot open %s\n", cfgfile);
 		exit(1);
 	}
-	printf("Configuring symlinks in %s based on firecfg.config\n", arg_bindir);
 
 	char buf[MAX_BUF];
 	int lineno = 0;
@@ -220,13 +244,59 @@ static void set_links_firecfg(void) {
 		if (*start == '\0')
 			continue;
 
+		// handle ignore command
+		if (*start == '!') {
+			append_ignorelist(start + 1);
+			continue;
+		}
+
+		// skip ignored programs
+		if (in_ignorelist(start)) {
+			printf("   %s ignored\n", start);
+			continue;
+		}
+
 		// set link
-		set_file(start, firejail_exec);
+		if (do_symlink)
+			set_file(start, FIREJAIL_EXEC);
 	}
 
 	fclose(fp);
-	free(cfgfile);
-	free(firejail_exec);
+	printf("\n");
+}
+
+// parse all config files matching pattern
+static void parse_config_glob(const char *pattern, int do_symlink) {
+	printf("Looking for config files in %s\n", pattern);
+
+	glob_t globbuf;
+	int globerr = glob(pattern, 0, NULL, &globbuf);
+	if (globerr == GLOB_NOMATCH) {
+		fprintf(stderr, "No matches for glob pattern %s\n", pattern);
+		goto out;
+	} else if (globerr != 0) {
+		fprintf(stderr, "Warning: Failed to match glob pattern %s: %s\n",
+		        pattern, strerror(errno));
+		goto out;
+	}
+
+	size_t i;
+	for (i = 0; i < globbuf.gl_pathc; i++)
+		parse_config_file(globbuf.gl_pathv[i], do_symlink);
+out:
+	globfree(&globbuf);
+}
+
+// parse all config files
+// do_symlink 0 just builds the ignorelist, 1 creates the symlinks
+void parse_config_all(int do_symlink) {
+	if (done_config)
+		return;
+
+	parse_config_glob(FIRECFG_CONF_GLOB, do_symlink);
+	parse_config_file(FIRECFG_CFGFILE, do_symlink);
+
+	done_config = 1;
 }
 
 // parse ~/.config/firejail/ directory
@@ -243,10 +313,6 @@ static void set_links_homedir(const char *homedir) {
 		return;
 	}
 
-	char *firejail_exec;
-	if (asprintf(&firejail_exec, "%s/bin/firejail", PREFIX) == -1)
-		errExit("asprintf");
-
 	// parse ~/.config/firejail/ directory
 	printf("\nConfiguring symlinks in %s based on local firejail config directory\n", arg_bindir);
 
@@ -257,6 +323,7 @@ static void set_links_homedir(const char *homedir) {
 		free(dirname);
 		return;
 	}
+	free(dirname);
 
 	struct dirent *entry;
 	while ((entry = readdir(dir))) {
@@ -267,26 +334,29 @@ static void set_links_homedir(const char *homedir) {
 		if (!exec)
 			errExit("strdup");
 		char *ptr = strrchr(exec, '.');
-		if (!ptr) {
-			free(exec);
-			continue;
-		}
-		if (strcmp(ptr, ".profile") != 0) {
-			free(exec);
-			continue;
-		}
+		if (!ptr)
+			goto next;
+		if (strcmp(ptr, ".profile") != 0)
+			goto next;
 
 		*ptr = '\0';
-		set_file(exec, firejail_exec);
+		if (in_ignorelist(exec)) {
+			printf("   %s ignored\n", exec);
+			goto next;
+		}
+
+		set_file(exec, FIREJAIL_EXEC);
+next:
 		free(exec);
 	}
 	closedir(dir);
-
-	free(firejail_exec);
 }
 
-static char *get_user(void) {
-	char *user = getenv("SUDO_USER");
+static const char *get_sudo_user(void) {
+	const char *doas_user = getenv("DOAS_USER");
+	const char *sudo_user = getenv("SUDO_USER");
+	const char *user = doas_user ? doas_user : sudo_user;
+
 	if (!user) {
 		user = getpwuid(getuid())->pw_name;
 		if (!user) {
@@ -298,13 +368,13 @@ static char *get_user(void) {
 	return user;
 }
 
-static char *get_homedir(const char *user, uid_t *uid, gid_t *gid) {
+static const char *get_homedir(const char *user, uid_t *uid, gid_t *gid) {
 	// find home directory
 	struct passwd *pw = getpwnam(user);
 	if (!pw)
 		goto errexit;
 
-	char *home = pw->pw_dir;
+	const char *home = pw->pw_dir;
 	if (!home)
 		goto errexit;
 
@@ -323,12 +393,11 @@ int main(int argc, char **argv) {
 	int bindir_set = 0;
 
 	// user setup
-	char *user = get_user();
+	const char *user = get_sudo_user();
 	assert(user);
 	uid_t uid;
 	gid_t gid;
-	char *home = get_homedir(user, &uid, &gid);
-
+	const char *home = get_homedir(user, &uid, &gid);
 
 	// check for --bindir
 	for (i = 1; i < argc; i++) {
@@ -364,7 +433,7 @@ int main(int argc, char **argv) {
 		else if (strcmp(argv[i], "--debug") == 0)
 			arg_debug = 1;
 		else if (strcmp(argv[i], "--version") == 0) {
-			printf("firecfg version %s\n\n", VERSION);
+			print_version();
 			return 0;
 		}
 		else if (strcmp(argv[i], "--clean") == 0) {
@@ -410,6 +479,7 @@ int main(int argc, char **argv) {
 		}
 	}
 
+	print_version();
 	if (arg_debug)
 		printf("%s %d %d %d %d\n", user, getuid(), getgid(), geteuid(), getegid());
 
@@ -443,18 +513,20 @@ int main(int argc, char **argv) {
 	}
 
 	if (arg_guide) {
+		const char *zenity_exec;
+		if (arg_debug)
+			zenity_exec = FZENITY_EXEC;
+		else
+			zenity_exec = ZENITY_EXEC;
+
 		char *cmd;
-if (arg_debug) {
-		if (asprintf(&cmd, "sudo %s/firejail/firejail-welcome.sh /usr/lib/firejail/fzenity %s %s", LIBDIR, SYSCONFDIR, user) == -1)
+		if (asprintf(&cmd, "%s %s %s %s %s",
+			     SUDO_EXEC, FIREJAIL_WELCOME_SH, zenity_exec, SYSCONFDIR, user) == -1)
 			errExit("asprintf");
-}
-else {
-		if (asprintf(&cmd, "sudo %s/firejail/firejail-welcome.sh /usr/bin/zenity %s %s", LIBDIR, SYSCONFDIR, user) == -1)
-			errExit("asprintf");
-}
+
 		int status = system(cmd);
 		if (status == -1) {
-			fprintf(stderr, "Error: cannot run firejail-welcome.sh\n");
+			fprintf(stderr, "Error: cannot run %s\n", FIREJAIL_WELCOME_SH);
 			exit(1);
 		}
 		free(cmd);
@@ -468,12 +540,12 @@ else {
 	// clear all symlinks
 	clean();
 
-	// set new symlinks based on /etc/firejail/firecfg.config
-	set_links_firecfg();
+	// set new symlinks based on config files
+	parse_config_all(1);
 
 	if (getuid() == 0) {
 		// add user to firejail access database - only for root
-		printf("\nAdding user %s to Firejail access database in %s/firejail.users\n", user, SYSCONFDIR);
+		printf("Adding user %s to Firejail access database in %s/firejail.users\n", user, SYSCONFDIR);
 		// temporarily set the umask, access database must be world-readable
 		mode_t orig_umask = umask(022);
 		firejail_user_add(user);
