@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -51,7 +51,6 @@ int checkcfg(int val) {
 			cfg_val[i] = 1; // most of them are enabled by default
 		cfg_val[CFG_RESTRICTED_NETWORK] = 0; // disabled by default
 		cfg_val[CFG_FORCE_NONEWPRIVS] = 0;
-		cfg_val[CFG_ETC_HIDE_BLACKLISTED] = 0;
 		cfg_val[CFG_PRIVATE_BIN_NO_LOCAL] = 0;
 		cfg_val[CFG_FIREJAIL_PROMPT] = 0;
 		cfg_val[CFG_DISABLE_MNT] = 0;
@@ -116,7 +115,6 @@ int checkcfg(int val) {
 			PARSE_YESNO(CFG_TRACELOG, "tracelog")
 			PARSE_YESNO(CFG_XEPHYR_WINDOW_TITLE, "xephyr-window-title")
 			PARSE_YESNO(CFG_OVERLAYFS, "overlayfs")
-			PARSE_YESNO(CFG_ETC_HIDE_BLACKLISTED, "etc-hide-blacklisted")
 			PARSE_YESNO(CFG_PRIVATE_BIN, "private-bin")
 			PARSE_YESNO(CFG_PRIVATE_BIN_NO_LOCAL, "private-bin-no-local")
 			PARSE_YESNO(CFG_PRIVATE_CACHE, "private-cache")
@@ -307,139 +305,135 @@ errout:
 	exit(1);
 }
 
-void print_version(void) {
-	printf("firejail version %s\n", VERSION);
-	printf("\n");
-	print_compiletime_support();
-	printf("\n");
-}
-
-void print_compiletime_support(void) {
-	printf("Compile time support:\n");
-	printf("\t- always force nonewprivs support is %s\n",
+static const char *const compiletime_support =
+	"Compile time support:"
+	"\n\t- always force nonewprivs support is "
 #ifdef HAVE_FORCE_NONEWPRIVS
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- AppArmor support is %s\n",
+	"\n\t- AppArmor support is "
 #ifdef HAVE_APPARMOR
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- AppImage support is %s\n",
+	"\n\t- AppImage support is "
 #ifdef LOOP_CTL_GET_FREE	// test for older kernels; this definition is found in /usr/include/linux/loop.h
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- chroot support is %s\n",
+	"\n\t- chroot support is "
 #ifdef HAVE_CHROOT
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- D-BUS proxy support is %s\n",
+	"\n\t- D-BUS proxy support is "
 #ifdef HAVE_DBUSPROXY
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- file transfer support is %s\n",
+	"\n\t- file transfer support is "
 #ifdef HAVE_FILE_TRANSFER
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- firetunnel support is %s\n",
-#ifdef HAVE_FIRETUNNEL
-		"enabled"
-#else
-		"disabled"
-#endif
-		);
-
-	printf("\t- IDS support is %s\n",
+	"\n\t- IDS support is "
 #ifdef HAVE_IDS
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- networking support is %s\n",
+	"\n\t- Landlock support is "
+#ifdef HAVE_LANDLOCK
+		"enabled"
+#else
+		"disabled"
+#endif
+
+	"\n\t- networking support is "
 #ifdef HAVE_NETWORK
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- output logging is %s\n",
+	"\n\t- output logging is "
 #ifdef HAVE_OUTPUT
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
-	printf("\t- overlayfs support is %s\n",
+
+	"\n\t- overlayfs support is "
 #ifdef HAVE_OVERLAYFS
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- private-home support is %s\n",
+	"\n\t- private-home support is "
 #ifdef HAVE_PRIVATE_HOME
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- private-cache and tmpfs as user %s\n",
+	"\n\t- private-lib support is "
+#ifdef HAVE_PRIVATE_LIB
+		"enabled"
+#else
+		"disabled"
+#endif
+
+	"\n\t- private-cache and tmpfs as user "
 #ifdef HAVE_USERTMPFS
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- SELinux support is %s\n",
+	"\n\t- sandbox check is "
+#ifdef HAVE_SANDBOX_CHECK
+		"enabled"
+#else
+		"disabled"
+#endif
+
+	"\n\t- SELinux support is "
 #ifdef HAVE_SELINUX
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- user namespace support is %s\n",
+	"\n\t- user namespace support is "
 #ifdef HAVE_USERNS
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
 
-	printf("\t- X11 sandboxing support is %s\n",
+	"\n\t- X11 sandboxing support is "
 #ifdef HAVE_X11
 		"enabled"
 #else
 		"disabled"
 #endif
-		);
+	"\n";
+
+void print_compiletime_support(void) {
+	puts(compiletime_support);
 }
