@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -67,11 +67,8 @@ static void disable_file(OPERATION op, const char *filename) {
 		// they don't seem to like a uid of 0
 		// force mounting
 		int fd = open(filename, O_PATH|O_CLOEXEC);
-		if (fd < 0) {
-			if (arg_debug)
-				printf("Warning (blacklisting): cannot open %s: %s\n", filename, strerror(errno));
+		if (fd < 0)
 			return;
-		}
 
 		EUID_ROOT();
 		int err = bind_mount_path_to_fd(RUN_RO_DIR, fd);
@@ -126,8 +123,8 @@ static void disable_file(OPERATION op, const char *filename) {
 	if (op == BLACKLIST_FILE || op == BLACKLIST_NOLOG) {
 		// some distros put all executables under /usr/bin and make /bin a symbolic link
 		if ((strcmp(fname, "/bin") == 0 || strcmp(fname, "/usr/bin") == 0) &&
-		      is_link(filename) &&
-		      S_ISDIR(s.st_mode)) {
+		    is_link(filename) &&
+		    S_ISDIR(s.st_mode)) {
 			fwarning("%s directory link was not blacklisted\n", filename);
 		}
 		else {
@@ -162,7 +159,7 @@ static void disable_file(OPERATION op, const char *filename) {
 				fs_logger2("blacklist-nolog", fname);
 
 			// files in /etc will be reprocessed during /etc rebuild
-			if (checkcfg(CFG_ETC_HIDE_BLACKLISTED) && strncmp(fname, "/etc/", 5) == 0) {
+			if (strncmp(fname, "/etc/", 5) == 0) {
 				ProfileEntry *prf = malloc(sizeof(ProfileEntry));
 				if (!prf)
 					errExit("malloc");
@@ -284,6 +281,8 @@ void fs_blacklist(void) {
 	if (!entry)
 		return;
 
+	timetrace_start();
+
 	size_t noblacklist_c = 0;
 	size_t noblacklist_m = 32;
 	char **noblacklist = calloc(noblacklist_m, sizeof(*noblacklist));
@@ -466,6 +465,8 @@ void fs_blacklist(void) {
 	for (i = 0; i < noblacklist_c; i++)
 		free(noblacklist[i]);
 	free(noblacklist);
+
+	fmessage("Base filesystem installed in %0.2f ms\n", timetrace_end());
 }
 
 //***********************************************
@@ -742,10 +743,20 @@ void fs_proc_sys_dev_boot(void) {
 
 	disable_file(BLACKLIST_FILE, "/sys/firmware");
 	disable_file(BLACKLIST_FILE, "/sys/hypervisor");
-	{ // allow user access to some directories in /sys/ by specifying 'noblacklist' option
-		profile_add("blacklist /sys/fs");
+
+	// Soft-block some paths in /sys/ (can be undone in profiles).
+	profile_add("blacklist /sys/fs");
+
+	// Hardware acceleration with the nvidia proprietary driver may fail
+	// without access to these paths (see #6372).
+	if (access("/dev/nvidiactl", R_OK) == 0 && arg_no3d == 0) {
+		profile_add("whitelist /sys/module/nvidia*");
+		profile_add("read-only /sys/module/nvidia*");
+	}
+	else {
 		profile_add("blacklist /sys/module");
 	}
+
 	disable_file(BLACKLIST_FILE, "/sys/power");
 	disable_file(BLACKLIST_FILE, "/sys/kernel/debug");
 	disable_file(BLACKLIST_FILE, "/sys/kernel/vmcoreinfo");
