@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -67,8 +67,10 @@ static void skel(const char *homedir) {
 		if (asprintf(&fname, "%s/.zshrc", homedir) == -1)
 			errExit("asprintf");
 		// don't copy it if we already have the file
-		if (access(fname, F_OK) == 0)
+		if (access(fname, F_OK) == 0) {
+			free(fname);
 			return;
+		}
 		if (is_link(fname)) { // access(3) on dangling symlinks fails, try again using lstat
 			fprintf(stderr, "Error: invalid %s file\n", fname);
 			exit(1);
@@ -91,8 +93,10 @@ static void skel(const char *homedir) {
 		if (asprintf(&fname, "%s/.cshrc", homedir) == -1)
 			errExit("asprintf");
 		// don't copy it if we already have the file
-		if (access(fname, F_OK) == 0)
+		if (access(fname, F_OK) == 0) {
+			free(fname);
 			return;
+		}
 		if (is_link(fname)) { // access(3) on dangling symlinks fails, try again using lstat
 			fprintf(stderr, "Error: invalid %s file\n", fname);
 			exit(1);
@@ -115,8 +119,10 @@ static void skel(const char *homedir) {
 		if (asprintf(&fname, "%s/.bashrc", homedir) == -1)
 			errExit("asprintf");
 		// don't copy it if we already have the file
-		if (access(fname, F_OK) == 0)
+		if (access(fname, F_OK) == 0) {
+			free(fname);
 			return;
+		}
 		if (is_link(fname)) { // access(3) on dangling symlinks fails, try again using lstat
 			fprintf(stderr, "Error: invalid %s file\n", fname);
 			exit(1);
@@ -185,20 +191,11 @@ static int store_asoundrc(void) {
 		errExit("asprintf");
 
 	struct stat s;
-	if (lstat(src, &s) == 0) {
-		if (S_ISLNK(s.st_mode)) {
-			// make sure the real path of the file is inside the home directory
-			/* coverity[toctou] */
-			char *rp = realpath(src, NULL);
-			if (!rp) {
-				fprintf(stderr, "Error: Cannot access %s\n", src);
-				exit(1);
-			}
-			if (strncmp(rp, cfg.homedir, strlen(cfg.homedir)) != 0 || rp[strlen(cfg.homedir)] != '/') {
-				fprintf(stderr, "Error: .asoundrc is a symbolic link pointing to a file outside home directory\n");
-				exit(1);
-			}
-			free(rp);
+	if (stat(src, &s) == 0) {
+		if (s.st_uid != getuid()) {
+			fwarning(".asoundrc is not owned by the current user, skipping...\n");
+			free(src);
+			return 0;
 		}
 
 		// create an empty file as root, and change ownership to user
@@ -361,7 +358,8 @@ void fs_private_homedir(void) {
 	}
 	EUID_USER();
 
-	skel(homedir);
+	if (!arg_keep_shell_rc)
+		skel(homedir);
 	if (xflag)
 		copy_xauthority();
 	if (aflag)
@@ -430,7 +428,8 @@ void fs_private(void) {
 		selinux_relabel_path(homedir, homedir);
 	}
 
-	skel(homedir);
+	if (!arg_keep_shell_rc)
+		skel(homedir);
 	if (xflag)
 		copy_xauthority();
 	if (aflag)
@@ -682,7 +681,8 @@ void fs_private_home_list(void) {
 		errExit("mounting tmpfs");
 	EUID_USER();
 
-	skel(homedir);
+	if (!arg_keep_shell_rc)
+		skel(homedir);
 	if (xflag)
 		copy_xauthority();
 	if (aflag)
