@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -24,7 +24,37 @@
 #include <dirent.h>
 #include <fcntl.h>
 
-void fs_hostname(const char *hostname) {
+// build a random host name
+static char *random_hostname(void) {
+	char vowels[] = { 'a', 'e', 'i', 'o', 'u'};
+	char consonants[] = {'b', 'c', 'c', 'c', 'g', 'h', 'h', 'h', 'h', 'h',
+		'j', 'j', 'k', 'k', 'k', 'k', 'k', 'k', 'k', 'k', 'k', 'k', 'm', 'm', 'm', 'm', 'n', 'n', 'n', 'n', 'n',
+		'r', 'r', 's', 's', 's', 's', 's', 's', 's', 's', 't', 't', 't', 't',
+		'w', 'y', 'y', 'y', 'y', 'z', 'z'};
+	char *ending[] = {"hiko", "hiko", "suke", "suke",  "suke", "shi", "shi", "ro", "ro",
+		"rou", "hito", "hito","ka"};
+
+	char *name = malloc(20);
+	if (!name)
+		errExit("malloc");
+
+	int i = 0;
+	name[i++] = consonants[rand() % sizeof(consonants)];
+	name[i++] = vowels[rand() % sizeof(vowels)];
+	name[i++] = consonants[rand() % sizeof(consonants)];
+	name[i++] = vowels[rand() % sizeof(vowels)];
+	if (rand() % 2) {
+		name[i++] = consonants[rand() % sizeof(consonants)];
+		name[i++] = vowels[rand() % sizeof(vowels)];
+	}
+	char *ptr = 	ending[rand() % (sizeof(ending) / sizeof(char *))];
+	strcpy(name + i, ptr);
+	return name;
+}
+
+void fs_hostname(void) {
+	if (!cfg.hostname)
+		cfg.hostname = random_hostname();
 	struct stat s;
 
 	// create a new /etc/hostname
@@ -33,6 +63,12 @@ void fs_hostname(const char *hostname) {
 			printf("Creating a new /etc/hostname file\n");
 
 		create_empty_file_as_root(RUN_HOSTNAME_FILE, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+		FILE *fp = fopen(RUN_HOSTNAME_FILE, "we");
+		if (!fp)
+			goto errexit;
+		fprintf(fp, "%s\n", cfg.hostname);
+		SET_PERMS_STREAM(fp, 0, 0, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+		fclose(fp);
 
 		// bind-mount the file on top of /etc/hostname
 		if (mount(RUN_HOSTNAME_FILE, "/etc/hostname", NULL, MS_BIND|MS_REC, NULL) < 0)
@@ -41,12 +77,12 @@ void fs_hostname(const char *hostname) {
 	}
 
 	// create a new /etc/hosts
-	if (cfg.hosts_file == NULL && stat("/etc/hosts", &s) == 0) {
+	if (stat(RUN_HOSTS_FILE2, &s) == 0) {
 		if (arg_debug)
 			printf("Creating a new /etc/hosts file\n");
 		// copy /etc/host into our new file, and modify it on the fly
 		/* coverity[toctou] */
-		FILE *fp1 = fopen("/etc/hosts", "re");
+		FILE *fp1 = fopen(RUN_HOSTS_FILE2, "re");
 		if (!fp1)
 			goto errexit;
 
@@ -67,7 +103,7 @@ void fs_hostname(const char *hostname) {
 			// copy line
 			if (strstr(buf, "127.0.0.1") && done == 0) {
 				done = 1;
-				fprintf(fp2, "%s %s\n", buf, hostname);
+				fprintf(fp2, "127.0.0.1 %s\n", cfg.hostname);
 			}
 			else
 				fprintf(fp2, "%s\n", buf);
@@ -83,7 +119,7 @@ void fs_hostname(const char *hostname) {
 	return;
 
 errexit:
-	fprintf(stderr, "Error: cannot create hostname file\n");
+	fprintf(stderr, "Error: cannot create /etc/hostname and /etc/hosts files\n");
 	exit(1);
 }
 
@@ -103,7 +139,10 @@ errexit:
 }
 
 void fs_store_hosts_file(void) {
-	copy_file_from_user_to_root(cfg.hosts_file, RUN_HOSTS_FILE, 0, 0, 0644); // root needed
+	if (cfg.hosts_file)
+		copy_file_from_user_to_root(cfg.hosts_file, RUN_HOSTS_FILE2, 0, 0, 0644); // root needed
+	else
+		copy_file_from_user_to_root("/etc/hosts", RUN_HOSTS_FILE2, 0, 0, 0644); // root needed
 }
 
 void fs_mount_hosts_file(void) {
@@ -113,7 +152,7 @@ void fs_mount_hosts_file(void) {
 	// check /etc/hosts file
 	struct stat s;
 	if (stat("/etc/hosts", &s) == -1)
-		goto errexit;
+		return;
 	// owned by root
 	if (s.st_uid != 0)
 		goto errexit;
