@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -89,31 +89,7 @@ int net_get_mtu(const char *ifname) {
 	return mtu;
 }
 
-void net_set_mtu(const char *ifname, int mtu) {
-	if (strlen(ifname) > IFNAMSIZ) {
-		fprintf(stderr, "Error: invalid network device name %s\n", ifname);
-		exit(1);
-	}
-
-	if (arg_debug)
-		printf("set interface %s MTU %d.\n", ifname, mtu);
-
-	int s;
-	struct ifreq ifr;
-
-	if ((s = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
-		errExit("socket");
-
-	memset(&ifr, 0, sizeof(ifr));
-	ifr.ifr_addr.sa_family = AF_INET;
-	strncpy(ifr.ifr_name, ifname, IFNAMSIZ - 1);
-	ifr.ifr_mtu = mtu;
-	if (ioctl(s, SIOCSIFMTU, (caddr_t)&ifr) != 0)
-		fwarning("cannot set mtu for interface %s\n", ifname);
-	close(s);
-}
-
-// return -1 if the interface was not found; if the interface was found retrn 0 and fill in IP address and mask
+// return -1 if the interface was not found; if the interface was found return 0 and fill in IP address and mask
 int net_get_if_addr(const char *bridge, uint32_t *ip, uint32_t *mask, uint8_t mac[6], int *mtu) {
 	assert(bridge);
 	assert(ip);
@@ -265,7 +241,7 @@ int net_get_mac(const char *ifname, unsigned char mac[6]) {
 	int sock;
 
 	if ((sock = socket(AF_INET, SOCK_STREAM, 0)) < 0)
-              	errExit("socket");
+		errExit("socket");
 
 	memset(&ifr, 0, sizeof(ifr));
 	strncpy(ifr.ifr_name, ifname, IFNAMSIZ - 1);
