@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -66,8 +66,8 @@ void check_output(int argc, char **argv) {
 	}
 
 	// do not accept directories, links, and files with ".."
-	if (strstr(outfile, "..") || is_link(outfile) || is_dir(outfile)) {
-		fprintf(stderr, "Error: invalid output file. Links, directories and files with \"..\" are not allowed.\n");
+	if (strstr(outfile, "..") || is_link(outfile) || is_dir(outfile) || has_cntrl_chars(outfile)) {
+		fprintf(stderr, "Error: invalid output file. Links, directories, files with \"..\" and control characters in filenames are not allowed.\n");
 		exit(1);
 	}
 
