@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -328,6 +328,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 	else if (strncmp(ptr, "name ", 5) == 0) {
 		cfg.name = ptr + 5;
 		if (strlen(cfg.name) == 0) {
+			fprintf(stderr, "Error: invalid sandbox name: cannot be empty\n");
+			exit(1);
+		}
+		if (invalid_name(cfg.name)) {
 			fprintf(stderr, "Error: invalid sandbox name\n");
 			exit(1);
 		}
@@ -367,8 +371,8 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		arg_caps_drop_all = 1;
 		return 0;
 	}
-	else if (strcmp(ptr, "shell none") == 0) {
-		fprintf(stderr, "Warning: \"shell none\" command in the profile file is done by default; the command will be deprecated\n");
+	else if (strcmp(ptr, "shell ") == 0) {
+		fprintf(stderr, "Warning: \"shell none\" is done by default now; the \"shell\" command has been removed\n");
 		return 0;
 	}
 	else if (strcmp(ptr, "tracelog") == 0) {
@@ -427,6 +431,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		arg_private_dev = 1;
 		return 0;
 	}
+	else if (strcmp(ptr, "keep-dev-ntsync") == 0) {
+		arg_keep_dev_ntsync = 1;
+		return 0;
+	}
 	else if (strcmp(ptr, "keep-dev-shm") == 0) {
 		arg_keep_dev_shm = 1;
 		return 0;
@@ -480,7 +488,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #endif
 		return 0;
 	}
-	else if (strncmp("dbus-user ", ptr, 10) == 0) {
+	else if (strncmp(ptr, "dbus-user ", 10) == 0) {
 #ifdef HAVE_DBUSPROXY
 		ptr += 10;
 		if (strcmp("filter", ptr) == 0) {
@@ -547,7 +555,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #endif
 		return 1;
 	}
-	else if (strncmp("dbus-system ", ptr, 12) == 0) {
+	else if (strncmp(ptr, "dbus-system ", 12) == 0) {
 #ifdef HAVE_DBUSPROXY
 		ptr += 12;
 		if (strcmp("filter", ptr) == 0) {
@@ -614,6 +622,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #endif
 		return 1;
 	}
+	else if (strcmp(ptr, "notpm") == 0) {
+		arg_notpm = 1;
+		return 0;
+	}
 	else if (strcmp(ptr, "nou2f") == 0) {
 		arg_nou2f = 1;
 		return 0;
@@ -631,9 +643,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #ifdef HAVE_NETWORK
 		if (checkcfg(CFG_NETWORK)) {
 			arg_netfilter = 1;
-			arg_netfilter_file = strdup(ptr + 10);
-			if (!arg_netfilter_file)
-				errExit("strdup");
+			arg_netfilter_file = expand_macros(ptr + 10);
 			check_netfilter_file(arg_netfilter_file);
 		}
 		else
@@ -645,9 +655,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #ifdef HAVE_NETWORK
 		if (checkcfg(CFG_NETWORK)) {
 			arg_netfilter6 = 1;
-			arg_netfilter6_file = strdup(ptr + 11);
-			if (!arg_netfilter6_file)
-				errExit("strdup");
+			arg_netfilter6_file = expand_macros(ptr + 11);
 			check_netfilter_file(arg_netfilter6_file);
 		}
 		else
@@ -1073,6 +1081,37 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+//#ifdef HAVE_LANDLOCK
+// landlock-common.inc is included by default.profile, so the entries of the
+// former should be processed or ignored instead of aborting.
+// Note that all landlock functions are empty when building without landlock
+// support.
+	if (strncmp(ptr, "landlock.enforce", 16) == 0) {
+		arg_landlock_enforce = 1;
+		return 0;
+	}
+	if (strncmp(ptr, "landlock.fs.read ", 17) == 0) {
+		ll_add_profile(LL_FS_READ, ptr + 17);
+		return 0;
+	}
+	if (strncmp(ptr, "landlock.fs.write ", 18) == 0) {
+		ll_add_profile(LL_FS_WRITE, ptr + 18);
+		return 0;
+	}
+	if (strncmp(ptr, "landlock.fs.makeipc ", 20) == 0) {
+		ll_add_profile(LL_FS_MAKEIPC, ptr + 20);
+		return 0;
+	}
+	if (strncmp(ptr, "landlock.fs.makedev ", 20) == 0) {
+		ll_add_profile(LL_FS_MAKEDEV, ptr + 20);
+		return 0;
+	}
+	if (strncmp(ptr, "landlock.fs.execute ", 20) == 0) {
+		ll_add_profile(LL_FS_EXEC, ptr + 20);
+		return 0;
+	}
+//#endif
+
 	// memory deny write&execute
 	if (strcmp(ptr, "memory-deny-write-execute") == 0) {
 		if (checkcfg(CFG_SECCOMP))
@@ -1084,8 +1123,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 
 	// restrict-namespaces
 	if (strcmp(ptr, "restrict-namespaces") == 0) {
-		if (checkcfg(CFG_SECCOMP))
+		if (checkcfg(CFG_SECCOMP)) {
+			arg_restrict_namespaces = 1;
 			profile_list_augment(&cfg.restrict_namespaces, "cgroup,ipc,net,mnt,pid,time,user,uts");
+		}
 		else
 			warning_feature_disabled("seccomp");
 		return 0;
@@ -1152,6 +1193,14 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 	// hostname
 	if (strncmp(ptr, "hostname ", 9) == 0) {
 		cfg.hostname = ptr + 9;
+		if (strlen(cfg.hostname) == 0) {
+			fprintf(stderr, "Error: invalid hostname: cannot be empty\n");
+			exit(1);
+		}
+		if (invalid_name(cfg.hostname)) {
+			fprintf(stderr, "Error: invalid hostname\n");
+			exit(1);
+		}
 		return 0;
 	}
 
@@ -1222,6 +1271,11 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+	if (strcmp(ptr, "keep-shell-rc") == 0) {
+		arg_keep_shell_rc = 1;
+		return 0;
+	}
+
 	// writable-var
 	if (strcmp(ptr, "writable-var") == 0) {
 		arg_writable_var = 1;
@@ -1366,6 +1420,20 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+	// private /etc without a list of files and directories
+	if (strcmp(ptr, "private-etc") == 0) {
+		if (checkcfg(CFG_PRIVATE_ETC)) {
+			if (arg_writable_etc) {
+				fprintf(stderr, "Error: --private-etc and --writable-etc are mutually exclusive\n");
+				exit(1);
+			}
+			arg_private_etc = 1;
+		}
+		else
+			warning_feature_disabled("private-etc");
+		return 0;
+	}
+
 	// private /opt list of files and directories
 	if (strncmp(ptr, "private-opt ", 12) == 0) {
 		if (checkcfg(CFG_PRIVATE_OPT)) {
@@ -1553,12 +1621,12 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			arg_rlimit_nofile = 1;
 		}
 		else if (strncmp(ptr, "rlimit-cpu ", 11) == 0) {
-			check_unsigned(ptr + 11, "Error: invalid rlimit in profile file: ");
+			check_unsigned(ptr + 11, "Error: invalid rlimit-cpu in profile file: ");
 			sscanf(ptr + 11, "%llu", &cfg.rlimit_cpu);
 			arg_rlimit_cpu = 1;
 		}
 		else if (strncmp(ptr, "rlimit-nproc ", 13) == 0) {
-			check_unsigned(ptr + 13, "Error: invalid rlimit in profile file: ");
+			check_unsigned(ptr + 13, "Error: invalid rlimit-nproc in profile file: ");
 			sscanf(ptr + 13, "%llu", &cfg.rlimit_nproc);
 			arg_rlimit_nproc = 1;
 		}
@@ -1571,7 +1639,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			arg_rlimit_fsize = 1;
 		}
 		else if (strncmp(ptr, "rlimit-sigpending ", 18) == 0) {
-			check_unsigned(ptr + 18, "Error: invalid rlimit in profile file: ");
+			check_unsigned(ptr + 18, "Error: invalid rlimit-sigpending in profile file: ");
 			sscanf(ptr + 18, "%llu", &cfg.rlimit_sigpending);
 			arg_rlimit_sigpending = 1;
 		}
@@ -1615,6 +1683,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			// set sandbox name and start normally
 			cfg.name = ptr + 14;
 			if (strlen(cfg.name) == 0) {
+				fprintf(stderr, "Error: invalid sandbox name: cannot be empty\n");
+				exit(1);
+			}
+			if (invalid_name(cfg.name)) {
 				fprintf(stderr, "Error: invalid sandbox name\n");
 				exit(1);
 			}
@@ -1727,7 +1799,7 @@ void profile_read(const char *fname) {
 	// check file
 	invalid_filename(fname, 0); // no globbing
 	if (strlen(fname) == 0 || is_dir(fname)) {
-		fprintf(stderr, "Error: invalid profile file\n");
+		fprintf(stderr, "Error: invalid profile file '%s'\n", fname);
 		exit(1);
 	}
 	if (access(fname, R_OK)) {
@@ -1735,10 +1807,16 @@ void profile_read(const char *fname) {
 		// if the file ends in ".local", do not exit
 		const char *base = gnu_basename(fname);
 		char *ptr = strstr(base, ".local");
-		if (ptr && strlen(ptr) == 6 && errsv != EACCES)
+		if (ptr && strlen(ptr) == 6 && errsv != EACCES) {
+			if (arg_debug) {
+				printf("Cannot access .local file %s: %s, skipping...\n",
+				       fname, strerror(errsv));
+			}
 			return;
+		}
 
-		fprintf(stderr, "Error: cannot access profile file: %s\n", fname);
+		fprintf(stderr, "Error: cannot access profile file %s: %s\n",
+		        fname, strerror(errsv));
 		exit(1);
 	}
 
@@ -1764,7 +1842,8 @@ void profile_read(const char *fname) {
 	// open profile file:
 	FILE *fp = fopen(fname, "re");
 	if (fp == NULL) {
-		fprintf(stderr, "Error: cannot open profile file %s\n", fname);
+		fprintf(stderr, "Error: cannot open profile file %s: %s\n",
+		        fname, strerror(errno));
 		exit(1);
 	}
 
@@ -1864,8 +1943,7 @@ void profile_read(const char *fname) {
 	fclose(fp);
 }
 
-char *profile_list_normalize(char *list)
-{
+char *profile_list_normalize(char *list) {
 	/* Remove redundant commas.
 	 *
 	 * As result is always shorter than original,
