@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -274,7 +274,7 @@ static void sandbox_if_up(Bridge *br) {
 	}
 
 	if (br->ip6sandbox)
-		 net_if_ip6(dev, br->ip6sandbox);
+		net_if_ip6(dev, br->ip6sandbox);
 }
 
 static void chk_chroot(void) {
@@ -516,6 +516,21 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 		printf("LD_PRELOAD=%s\n", getenv("LD_PRELOAD"));
 	}
 
+#ifdef HAVE_LANDLOCK
+	//****************************
+	// Configure Landlock
+	//****************************
+	if (arg_landlock_enforce && ll_restrict(0)) {
+		// It isn't safe to continue if Landlock self-restriction was
+		// enabled and the "landlock_restrict_self" syscall has failed.
+		fprintf(stderr, "Error: ll_restrict() failed, exiting...\n");
+		exit(1);
+	} else {
+		if (arg_debug)
+			fprintf(stderr, "Not enforcing Landlock\n");
+	}
+#endif
+
 	if (just_run_the_shell) {
 		char *arg[2];
 		arg[0] = cfg.usershell;
@@ -580,8 +595,6 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 			if (arg_debug)
 				printf("Running %s command through %s\n", cfg.command_line, cfg.usershell);
 			arg[index++] = "-c";
-			if (arg_doubledash)
-				arg[index++] = "--";
 			arg[index++] = cfg.command_line;
 		}
 		else if (login_shell) {
@@ -652,12 +665,12 @@ int sandbox(void* sandbox_arg) {
 	if (arg_debug)
 		printf("Initializing child process\n");
 
- 	// close each end of the unused pipes
- 	close(parent_to_child_fds[1]);
- 	close(child_to_parent_fds[0]);
+	// close each end of the unused pipes
+	close(parent_to_child_fds[1]);
+	close(child_to_parent_fds[0]);
 
- 	// wait for parent to do base setup
- 	wait_for_other(parent_to_child_fds[0]);
+	// wait for parent to do base setup
+	wait_for_other(parent_to_child_fds[0]);
 
 	if (arg_debug && child_pid == 1)
 		printf("PID namespace installed\n");
@@ -850,8 +863,7 @@ int sandbox(void* sandbox_arg) {
 		fs_trace_touch_or_store_preload();
 
 	// store hosts file
-	if (cfg.hosts_file)
-		fs_store_hosts_file();
+	fs_store_hosts_file();
 
 	//****************************
 	// configure filesystem
@@ -881,7 +893,8 @@ int sandbox(void* sandbox_arg) {
 	//****************************
 	// appimage
 	//****************************
-	appimage_mount();
+	if (arg_appimage)
+		appimage_mount();
 
 	//****************************
 	// private mode
@@ -952,6 +965,7 @@ int sandbox(void* sandbox_arg) {
 		}
 	}
 
+#ifdef HAVE_PRIVATE_LIB
 	// private-lib is disabled for appimages
 	if (arg_private_lib && !arg_appimage) {
 		if (cfg.chrootdir)
@@ -962,6 +976,7 @@ int sandbox(void* sandbox_arg) {
 			fs_private_lib();
 		}
 	}
+#endif
 
 #ifdef HAVE_USERTMPFS
 	if (arg_private_cache) {
@@ -988,11 +1003,7 @@ int sandbox(void* sandbox_arg) {
 	//****************************
 	// hosts and hostname
 	//****************************
-	if (cfg.hostname)
-		fs_hostname(cfg.hostname);
-
-	if (cfg.hosts_file)
-		fs_mount_hosts_file();
+	fs_hostname();
 
 	//****************************
 	// /etc overrides from the network namespace
@@ -1032,6 +1043,7 @@ int sandbox(void* sandbox_arg) {
 			 * 3. mount RUN_ETC_DIR at /etc
 			 */
 			timetrace_start();
+			cfg.etc_private_keep = fs_etc_build(cfg.etc_private_keep);
 			fs_private_dir_copy("/etc", RUN_ETC_DIR, cfg.etc_private_keep);
 
 			if (umount2("/etc/group", MNT_DETACH) == -1)
@@ -1048,7 +1060,8 @@ int sandbox(void* sandbox_arg) {
 
 			// openSUSE configuration is split between /etc and /usr/etc
 			// process private-etc a second time
-			fs_private_dir_list("/usr/etc", RUN_USR_ETC_DIR, cfg.etc_private_keep);
+			if (access("/usr/etc", F_OK) == 0)
+				fs_private_dir_list("/usr/etc", RUN_USR_ETC_DIR, cfg.etc_private_keep);
 		}
 	}
 
@@ -1088,6 +1101,9 @@ int sandbox(void* sandbox_arg) {
 	if (arg_nodvd)
 		fs_dev_disable_dvd();
 
+	if (arg_notpm)
+		fs_dev_disable_tpm();
+
 	if (arg_nou2f)
 		fs_dev_disable_u2f();
 
@@ -1097,11 +1113,14 @@ int sandbox(void* sandbox_arg) {
 	if (arg_noinput)
 		fs_dev_disable_input();
 
+	if (!arg_keep_dev_ntsync)
+		fs_dev_disable_ntsync();
+
 	//****************************
-	// rebuild etc directory, set dns
+	// set DNS
 	//****************************
-	if (!arg_writable_etc)
-		fs_rebuild_etc();
+	if (cfg.dns1 != NULL || any_dhcp())
+		fs_resolvconf();
 
 	//****************************
 	// start dhcp client
@@ -1214,7 +1233,19 @@ int sandbox(void* sandbox_arg) {
 		seccomp_load(RUN_SECCOMP_MDWX_32);
 	}
 
-	if (cfg.restrict_namespaces) {
+	if (arg_restrict_namespaces) {
+		if (arg_seccomp_error_action != EPERM) {
+			seccomp_filter_namespaces(true, cfg.restrict_namespaces);
+			seccomp_filter_namespaces(false, cfg.restrict_namespaces);
+		}
+
+		if (arg_debug)
+			printf("Install namespaces filter\n");
+		seccomp_load(RUN_SECCOMP_NS);	// install filter
+		seccomp_load(RUN_SECCOMP_NS_32);
+
+	}
+	else if (cfg.restrict_namespaces) {
 		seccomp_filter_namespaces(true, cfg.restrict_namespaces);
 		seccomp_filter_namespaces(false, cfg.restrict_namespaces);
 
@@ -1259,13 +1290,13 @@ int sandbox(void* sandbox_arg) {
 	}
 
 	// notify parent that new user namespace has been created so a proper
- 	// UID/GID map can be setup
- 	notify_other(child_to_parent_fds[1]);
- 	close(child_to_parent_fds[1]);
+	// UID/GID map can be setup
+	notify_other(child_to_parent_fds[1]);
+	close(child_to_parent_fds[1]);
 
- 	// wait for parent to finish setting up a proper UID/GID map
- 	wait_for_other(parent_to_child_fds[0]);
- 	close(parent_to_child_fds[0]);
+	// wait for parent to finish setting up a proper UID/GID map
+	wait_for_other(parent_to_child_fds[0]);
+	close(parent_to_child_fds[0]);
 
 	// somehow, the new user namespace resets capabilities;
 	// we need to do them again
@@ -1278,10 +1309,7 @@ int sandbox(void* sandbox_arg) {
 	//****************************************
 	// Set NO_NEW_PRIVS if desired
 	//****************************************
-#ifndef HAVE_FORCE_NONEWPRIVS
-	if (arg_nonewprivs)
-#endif
-	{
+	if (arg_nonewprivs) {
 		if (prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0) != 0) {
 			fprintf(stderr, "Error: cannot set NO_NEW_PRIVS, it requires a Linux kernel version 3.5 or newer.\n");
 			exit(1);
