@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -26,6 +26,7 @@
 #include <sys/resource.h>
 #include <sys/wait.h>
 #include "../include/seccomp.h"
+#include "../include/gcov_wrapper.h"
 
 #include <fcntl.h>
 #ifndef O_PATH
@@ -131,6 +132,24 @@ static int __attribute__((noreturn)) sbox_do_exec_v(unsigned filtermask, char *
 #ifdef SYS_umount2
 			BLACKLIST(SYS_umount2),
 #endif
+#ifdef SYS_fsopen
+			BLACKLIST(SYS_fsopen), // mount syscalls introduced 2019
+#endif
+#ifdef SYS_fsconfig
+			BLACKLIST(SYS_fsconfig),
+#endif
+#ifdef SYS_fsmount
+			BLACKLIST(SYS_fsmount),
+#endif
+#ifdef SYS_move_mount
+			BLACKLIST(SYS_move_mount),
+#endif
+#ifdef SYS_fspick
+			BLACKLIST(SYS_fspick),
+#endif
+#ifdef SYS_open_tree
+			BLACKLIST(SYS_open_tree),
+#endif
 #ifdef SYS_ptrace
 			BLACKLIST(SYS_ptrace), // trace processes
 #endif
@@ -184,6 +203,9 @@ static int __attribute__((noreturn)) sbox_do_exec_v(unsigned filtermask, char *
 #endif
 #ifdef SYS_syslog
 			BLACKLIST(SYS_syslog), // kernel printk control
+#endif
+#ifdef SYS_personality
+			BLACKLIST(SYS_personality), // execution domain
 #endif
 			RETURN_ALLOW
 		};
@@ -238,6 +260,7 @@ static int __attribute__((noreturn)) sbox_do_exec_v(unsigned filtermask, char *
 			fprintf(stderr, "Error: %s is world writable, refusing to execute\n", arg[0]);
 			exit(1);
 		}
+		__gcov_dump();
 		fexecve(fd, arg, new_environment);
 	} else {
 		assert(0);
