@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -19,7 +19,7 @@
 */
 #include "firejail.h"
 
-static char *usage_str =
+static const char *const usage_str =
 	"Firejail is a SUID sandbox program that reduces the risk of security breaches by\n"
 	"restricting the running environment of untrusted applications using Linux\n"
 	"namespaces.\n"
@@ -30,10 +30,12 @@ static char *usage_str =
 	"    -- - signal the end of options and disables further option processing.\n"
 	"    --allow-debuggers - allow tools such as strace and gdb inside the sandbox.\n"
 	"    --allusers - all user home directories are visible inside the sandbox.\n"
+#ifdef HAVE_APPARMOR
 	"    --apparmor - enable AppArmor confinement with the default profile.\n"
 	"    --apparmor=profile_name - enable AppArmor confinement with a\n"
 	"\tcustom profile.\n"
 	"    --apparmor.print=name|pid - print apparmor status.\n"
+#endif
 	"    --appimage - sandbox an AppImage application.\n"
 #ifdef HAVE_NETWORK
 	"    --bandwidth=name|pid - set bandwidth limits.\n"
@@ -79,7 +81,9 @@ static char *usage_str =
 	"    --debug-blacklists - debug blacklisting.\n"
 	"    --debug-caps - print all recognized capabilities.\n"
 	"    --debug-errnos - print all recognized error numbers.\n"
+#ifdef HAVE_PRIVATE_LIB
 	"    --debug-private-lib - debug for --private-lib option.\n"
+#endif
 	"    --debug-protocols - print all recognized protocols.\n"
 	"    --debug-syscalls - print all recognized system calls.\n"
 	"    --debug-syscalls32 - print all recognized 32 bit system calls.\n"
@@ -125,9 +129,19 @@ static char *usage_str =
 #endif
 	"    --join-or-start=name|pid - join the sandbox or start a new one.\n"
 	"    --keep-config-pulse - disable automatic ~/.config/pulse init.\n"
+	"    --keep-dev-ntsync - /dev/ntsync character device is untouched (even with --private-dev).\n"
 	"    --keep-dev-shm - /dev/shm directory is untouched (even with --private-dev).\n"
 	"    --keep-fd - inherit open file descriptors to sandbox.\n"
+	"    --keep-shell-rc - do not copy shell rc files from /etc/skel\n"
 	"    --keep-var-tmp - /var/tmp directory is untouched.\n"
+#ifdef HAVE_LANDLOCK
+	"    --landlock.enforce - enforce the Landlock ruleset.\n"
+	"    --landlock.fs.read=path - add a read access rule for the path to the Landlock ruleset.\n"
+	"    --landlock.fs.write=path - add a write access rule for the path to the Landlock ruleset.\n"
+	"    --landlock.fs.makeipc=path - add an access rule for the path to the Landlock ruleset for creating named pipes and sockets.\n"
+	"    --landlock.fs.makedev=path - add an access rule for the path to the Landlock ruleset for creating block/char devices.\n"
+	"    --landlock.fs.execute=path - add an execute access rule for the path to the Landlock ruleset.\n"
+#endif
 	"    --list - list all sandboxes.\n"
 #ifdef HAVE_FILE_TRANSFER
 	"    --ls=name|pid dir_or_filename - list files in sandbox container.\n"
@@ -176,8 +190,8 @@ static char *usage_str =
 	"    --noroot - install a user namespace with only the current user.\n"
 #endif
 	"    --nosound - disable sound system.\n"
-	"    --noautopulse - disable automatic ~/.config/pulse init.\n"
 	"    --novideo - disable video devices.\n"
+	"    --notpm - disable TPM devices.\n"
 	"    --nou2f - disable U2F devices.\n"
 	"    --nowhitelist=filename - disable whitelist for file or directory.\n"
 	"    --oom=value - configure OutOfMemory killer for the sandbox\n"
@@ -197,14 +211,17 @@ static char *usage_str =
 	"    --private=directory - use directory as user home.\n"
 	"    --private-cache - temporary ~/.cache directory.\n"
 	"    --private-home=file,directory - build a new user home in a temporary\n"
-	"\tfilesystem, and copy the files and directories in the list in\n"
-	"\tthe new home.\n"
+	"\tfilesystem, and copy the files and directories in the list in the\n"
+	"\tnew home.\n"
 	"    --private-bin=file,file - build a new /bin in a temporary filesystem,\n"
 	"\tand copy the programs in the list.\n"
 	"    --private-dev - create a new /dev directory with a small number of\n"
 	"\tcommon device files.\n"
 	"    --private-etc=file,directory - build a new /etc in a temporary\n"
 	"\tfilesystem, and copy the files and directories in the list.\n"
+#ifdef HAVE_PRIVATE_LIB
+	"    --private-lib - create a private /lib directory\n"
+#endif
 	"    --private-tmp - mount a tmpfs on top of /tmp directory.\n"
 	"    --private-cwd - do not inherit working directory inside jail.\n"
 	"    --private-cwd=directory - set working directory inside jail.\n"
@@ -303,11 +320,18 @@ static char *usage_str =
 	"\tlist all running sandboxes\n"
 	"\n"
 	"License GPL version 2 or later\n"
-	"Homepage: https://firejail.wordpress.com\n"
-	"\n";
+	"Homepage: https://firejail.wordpress.com\n";
 
+void print_version(FILE *stream) {
+	fprintf(stream, "firejail version %s\n\n", VERSION);
+}
+
+void print_version_full(void) {
+	print_version(stdout);
+	print_compiletime_support();
+}
 
 void usage(void) {
-	printf("firejail - version %s\n\n", VERSION);
+	print_version(stdout);
 	puts(usage_str);
 }
