@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -56,7 +56,8 @@ long long unsigned parse_arg_size(char *str) {
 	}
 
 	/* checks for is value valid positive number */
-	for (int i = 0; i < len; i++) {
+	int i;
+	for (i = 0; i < len; i++) {
 		if (!isdigit(*(str+i))) {
 			return 0;
 		}
@@ -206,6 +207,8 @@ static void clean_supplementary_groups(gid_t gid) {
 	if (!arg_nosound) {
 		copy_group_ifcont("audio", groups, ngroups,
 		                  new_groups, &new_ngroups, MAX_GROUPS);
+		copy_group_ifcont("pipewire", groups, ngroups,
+		                  new_groups, &new_ngroups, MAX_GROUPS);
 	}
 
 	if (!arg_novideo) {
@@ -237,6 +240,11 @@ static void clean_supplementary_groups(gid_t gid) {
 		                  new_groups, &new_ngroups, MAX_GROUPS);
 	}
 
+	if (!arg_nou2f) {
+		copy_group_ifcont("plugdev", groups, ngroups,
+				  new_groups, &new_ngroups, MAX_GROUPS);
+	}
+
 	if (new_ngroups) {
 		rv = setgroups(new_ngroups, new_groups);
 		if (rv)
@@ -255,7 +263,6 @@ static void clean_supplementary_groups(gid_t gid) {
 	return;
 
 clean_all:
-	fwarning("cleaning all supplementary groups\n");
 	if (setgroups(0, NULL) < 0)
 		errExit("setgroups");
 }
@@ -559,10 +566,8 @@ int is_dir(const char *fname) {
 		rv = stat_as_user(fname, &s);
 	else {
 		char *tmp;
-		if (asprintf(&tmp, "%s/", fname) == -1) {
-			fprintf(stderr, "Error: cannot allocate memory, %s:%d\n", __FILE__, __LINE__);
+		if (asprintf(&tmp, "%s/", fname) == -1)
 			errExit("asprintf");
-		}
 		rv = stat_as_user(tmp, &s);
 		free(tmp);
 	}
@@ -1102,7 +1107,7 @@ void mkdir_attr(const char *fname, mode_t mode, uid_t uid, gid_t gid) {
 	if (mkdir(fname, mode) == -1 ||
 	    chmod(fname, mode) == -1 ||
 	    chown(fname, uid, gid)) {
-	    	fprintf(stderr, "Error: failed to create %s directory\n", fname);
+		fprintf(stderr, "Error: failed to create %s directory\n", fname);
 		errExit("mkdir/chmod");
 	}
 
@@ -1324,7 +1329,7 @@ void close_all(int *keep_list, size_t sz) {
 		if (fd == dirfd(dir))
 			continue; // just postponed
 
-		// dont't close file descriptors in keep list
+		// don't close file descriptors in keep list
 		int keep = 0;
 		if (keep_list) {
 			size_t i;
@@ -1338,6 +1343,13 @@ void close_all(int *keep_list, size_t sz) {
 		if (keep)
 			continue;
 
+#ifdef HAVE_LANDLOCK
+		// Don't close the file descriptor of the Landlock ruleset; it
+		// will be automatically closed by the "ll_restrict" wrapper
+		// function.
+		if (fd == ll_get_fd())
+			continue;
+#endif
 		close(fd);
 	}
 	closedir(dir);
@@ -1385,6 +1397,7 @@ void enter_network_namespace(pid_t pid) {
 		fprintf(stderr, "Error: the sandbox doesn't use a new network namespace\n");
 		exit(1);
 	}
+	free(name);
 
 	// join the namespace
 	EUID_ROOT();
@@ -1449,6 +1462,79 @@ static int has_link(const char *dir) {
 	return 0;
 }
 
+int ascii_isalnum(unsigned char c) {
+	return (ascii_isalpha(c) || ascii_isdigit(c));
+}
+
+int ascii_isalpha(unsigned char c) {
+	return (ascii_islower(c) || ascii_isupper(c));
+}
+
+int ascii_isdigit(unsigned char c) {
+	return (c >= '0' && c <= '9');
+}
+
+int ascii_islower(unsigned char c) {
+	return (c >= 'a' && c <= 'z');
+}
+
+int ascii_isupper(unsigned char c) {
+	return (c >= 'A' && c <= 'Z');
+}
+
+int ascii_isxdigit(unsigned char c) {
+	int ret = (ascii_isdigit(c) ||
+	          (c >= 'a' && c <= 'f') ||
+	          (c >= 'A' && c <= 'F'));
+	return ret;
+}
+
+// Note: Keep this in sync with NAME VALIDATION in src/man/firejail.1.in.
+//
+// Allow only ASCII letters, digits and a few special characters; names with
+// only numbers are rejected; spaces and control characters are rejected.
+int invalid_name(const char *name) {
+	const char *c = name;
+	int only_numbers = 1;
+
+	if (strlen(name) > 253)
+		return 1;
+
+	// must start with alnum
+	if (!ascii_isalnum(*c))
+		return 1;
+	if (!ascii_isdigit(*c))
+		only_numbers = 0;
+	++c;
+
+	while (*c) {
+		switch (*c) {
+		case '-':
+		case '.':
+		case '_':
+			only_numbers = 0;
+			break;
+		default:
+			if (!ascii_isalnum(*c))
+				return 1;
+			if (!ascii_isdigit(*c))
+				only_numbers = 0;
+		}
+		++c;
+	}
+
+	// must end with alnum
+	--c;
+	if (!ascii_isalnum(*c))
+		return 1;
+
+	if (only_numbers)
+		return 1;
+
+	return 0;
+}
+
+
 void check_homedir(const char *dir) {
 	assert(dir);
 	if (dir[0] != '/') {
