@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -19,9 +19,12 @@
 */
 #include "fsec_print.h"
 
+static const char *const usage_str =
+	"Usage:\n"
+	"\tfsec-print file - disassemble seccomp filter\n";
+
 static void usage(void) {
-	printf("Usage:\n");
-	printf("\tfsec-print file - disassemble seccomp filter\n");
+	puts(usage_str);
 }
 
 int arg_quiet = 0;
@@ -47,7 +50,7 @@ int main(int argc, char **argv) {
 //system("cat /proc/self/status");
 int i;
 for (i = 0; i < argc; i++)
-        printf("*%s* ", argv[i]);
+	printf("*%s* ", argv[i]);
 printf("\n");
 }
 #endif
