@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -32,11 +32,22 @@
 #include <ctype.h>
 #include <assert.h>
 
+#if !defined(__func__) && defined(__FUNCTION__)
+#define __func__ __FUNCTION__
+#endif
+
 // dbus proxy path used by firejail and firemon
 #define XDG_DBUS_PROXY_PATH "/usr/bin/xdg-dbus-proxy"
 
+#define errExit(msg) _errExit(__FILE__, __LINE__, __func__, msg)
 
-#define errExit(msg)    do { char msgout[500]; snprintf(msgout, 500, "Error %s: %s:%d %s", msg, __FILE__, __LINE__, __FUNCTION__); perror(msgout); exit(1);} while (0)
+static inline void __attribute__((noreturn))
+_errExit(const char *fname, int lineno, const char *func, const char *msg) {
+	char msgout[500];
+	snprintf(msgout, 500, "Error %s:%d: %s: %s", fname, lineno, func, msg);
+	perror(msgout);
+	exit(1);
+}
 
 // macro to print ip addresses in a printf statement
 #define PRINT_IP(A) \
@@ -143,6 +154,7 @@ int pid_proc_cmdline_x11_xpra_xephyr(const pid_t pid);
 int pid_hidepid(void);
 char *do_replace_cntrl_chars(char *str, char c);
 char *replace_cntrl_chars(const char *str, char c);
+char *escape_cntrl_chars(const char *str);
 int has_cntrl_chars(const char *str);
 void reject_cntrl_chars(const char *fname);
 void reject_meta_chars(const char *fname, int globbing);
