@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -55,6 +55,7 @@ void noexec_setup(void) {
 			execfile_len = s.st_size;
 			close(fd);
 		}
+		free(self);
 	}
 }
 
@@ -76,7 +77,7 @@ void noexec_test(const char *path) {
 
 	if (child == 0) { // child
 		// drop privileges
- 		if (setgid(user_gid) != 0)
+		if (setgid(user_gid) != 0)
 			errExit("setgid");
 		if (setuid(user_uid) != 0)
 			errExit("setuid");
@@ -110,4 +111,5 @@ void noexec_test(const char *path) {
 	wait(&status);
 	int rv = unlink(fname);
 	(void) rv;
+	free(fname);
 }
