@@ -1,6 +1,6 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2022 Firejail Authors
+# Copyright (C) 2014-2025 Firejail Authors
 # License GPL v2
 
 # not currently covered
@@ -11,7 +11,8 @@
 #                          install contrib scripts
 #  --enable-analyzer       enable GCC 10 static analyzer
 
-
+# shellcheck source=config.sh
+. "$(dirname "$0")/../../config.sh" || exit 1
 
 arr[1]="TEST 1: standard compilation"
 arr[2]="TEST 2: compile dbus proxy disabled"
@@ -51,7 +52,7 @@ print_title() {
 	echo "**************************************************"
 }
 
-DIST="$1"
+DIST="$TARNAME-$VERSION"
 while [[ $# -gt 0 ]]; do    # Until you run out of parameters . . .
 	case "$1" in
 	--clean)
@@ -79,9 +80,11 @@ echo "$DIST"
 tar -xJvf ../../"$DIST.tar.xz"
 mv "$DIST" firejail
 
-cd firejail
-./configure --prefix=/usr --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+cd firejail || exit 1
+./configure --prefix=/usr --enable-fatal-warnings \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test1
 grep Error output-configure output-make >> ./report-test1
@@ -95,10 +98,13 @@ rm output-configure output-make
 # - disable dbus proxy configuration
 #*****************************************************************
 print_title "${arr[2]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-dbusproxy --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-dbusproxy \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test2
 grep Error output-configure output-make >> ./report-test2
@@ -112,10 +118,13 @@ rm output-configure output-make
 # - disable chroot configuration
 #*****************************************************************
 print_title "${arr[3]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-chroot --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-chroot \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test3
 grep Error output-configure output-make >> ./report-test3
@@ -129,10 +138,13 @@ rm output-configure output-make
 # - disable firetunnel configuration
 #*****************************************************************
 print_title "${arr[4]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-firetunnel --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-firetunnel \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test4
 grep Error output-configure output-make >> ./report-test4
@@ -146,10 +158,13 @@ rm output-configure output-make
 # - disable user namespace configuration
 #*****************************************************************
 print_title "${arr[5]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-userns --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-userns \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test5
 grep Error output-configure output-make >> ./report-test5
@@ -164,10 +179,13 @@ rm output-configure output-make
 # - check compilation
 #*****************************************************************
 print_title "${arr[6]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-network --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-network \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test6
 grep Error output-configure output-make >> ./report-test6
@@ -181,10 +199,13 @@ rm output-configure output-make
 # - disable X11 support
 #*****************************************************************
 print_title "${arr[7]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-x11 --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-x11 \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test7
 grep Error output-configure output-make >> ./report-test7
@@ -198,10 +219,13 @@ rm output-configure output-make
 # - enable selinux
 #*****************************************************************
 print_title "${arr[8]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --enable-selinux --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --enable-selinux \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test8
 grep Error output-configure output-make >> ./report-test8
@@ -215,10 +239,13 @@ rm output-configure output-make
 # - disable file transfer
 #*****************************************************************
 print_title "${arr[9]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-file-transfer --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-file-transfer \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test9
 grep Error output-configure output-make >> ./report-test9
@@ -232,10 +259,13 @@ rm output-configure output-make
 # - disable whitelist
 #*****************************************************************
 print_title "${arr[10]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-whitelist --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-whitelist \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test10
 grep Error output-configure output-make >> ./report-test10
@@ -249,10 +279,13 @@ rm output-configure output-make
 # - disable global config
 #*****************************************************************
 print_title "${arr[11]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-globalcfg --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-globalcfg \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test11
 grep Error output-configure output-make >> ./report-test11
@@ -266,10 +299,13 @@ rm output-configure output-make
 # - enable apparmor
 #*****************************************************************
 print_title "${arr[12]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --enable-apparmor --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --enable-apparmor \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test12
 grep Error output-configure output-make >> ./report-test12
@@ -283,10 +319,13 @@ rm output-configure output-make
 # - enable busybox workaround
 #*****************************************************************
 print_title "${arr[13]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --enable-busybox-workaround --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --enable-busybox-workaround \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test13
 grep Error output-configure output-make >> ./report-test13
@@ -300,10 +339,13 @@ rm output-configure output-make
 # - disable overlayfs
 #*****************************************************************
 print_title "${arr[14]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-overlayfs --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-overlayfs \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test14
 grep Error output-configure output-make >> ./report-test14
@@ -317,10 +359,13 @@ rm output-configure output-make
 # - disable private home
 #*****************************************************************
 print_title "${arr[15]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-private-home --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-private-home \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test15
 grep Error output-configure output-make >> ./report-test15
@@ -334,10 +379,13 @@ rm output-configure output-make
 # - disable manpages
 #*****************************************************************
 print_title "${arr[16]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-man --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-man \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test16
 grep Error output-configure output-make >> ./report-test16
@@ -351,10 +399,13 @@ rm output-configure output-make
 # - disable tmpfs as regular user"
 #*****************************************************************
 print_title "${arr[17]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-usertmpfs --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-usertmpfs \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test17
 grep Error output-configure output-make >> ./report-test17
@@ -368,10 +419,13 @@ rm output-configure output-make
 # - disable private home feature
 #*****************************************************************
 print_title "${arr[18]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --disable-private-home --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --disable-private-home \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test18
 grep Error output-configure output-make >> ./report-test18
@@ -385,10 +439,13 @@ rm output-configure output-make
 # - enable ids
 #*****************************************************************
 print_title "${arr[19]}"
-cd firejail
+cd firejail || exit 1
 make distclean
-./configure --prefix=/usr --enable-ids --enable-fatal-warnings 2>&1 | tee ../output-configure
-make -j4 2>&1 | tee ../output-make
+./configure --prefix=/usr --enable-fatal-warnings \
+  --enable-ids \
+  2>&1 | tee ../output-configure
+
+make -j "$(nproc)" 2>&1 | tee ../output-make
 cd ..
 grep Warning output-configure output-make > ./report-test19
 grep Error output-configure output-make >> ./report-test19
