@@ -1,6 +1,6 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2022 Firejail Authors
+# Copyright (C) 2014-2025 Firejail Authors
 # License GPL v2
 
 export MALLOC_CHECK_=3
@@ -80,12 +80,6 @@ rm -fr ~/_firejail_test_dir1
 rm -f ~/_firejail_test_link1
 rm -f ~/_firejail_test_link2
 
-echo "TESTING: private-etc (test/fs/private-etc.exp)"
-./private-etc.exp
-
-echo "TESTING: empty private-etc (test/fs/private-etc-empty.exp)"
-./private-etc-empty.exp
-
 echo "TESTING: private-bin (test/fs/private-bin.exp)"
 ./private-bin.exp
 
